@@ -1,13 +1,17 @@
 from .entry import ArchiveEntry
 from .exception import ArchiveError
 from .extract import extract_fd, extract_file, extract_memory
-from .read import fd_reader, file_reader, memory_reader
+from .read import (
+    custom_reader, fd_reader, file_reader, memory_reader, stream_reader,
+    seekable_stream_reader
+)
 from .write import custom_writer, fd_writer, file_writer, memory_writer
 
-__all__ = [
+__all__ = [x.__name__ for x in (
     ArchiveEntry,
     ArchiveError,
     extract_fd, extract_file, extract_memory,
-    fd_reader, file_reader, memory_reader,
+    custom_reader, fd_reader, file_reader, memory_reader, stream_reader,
+    seekable_stream_reader,
     custom_writer, fd_writer, file_writer, memory_writer
-]
+)]
